You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by GitBox <gi...@apache.org> on 2018/11/28 12:08:27 UTC

[GitHub] brodybits closed pull request #172: cleanup support for osx platform (macOS)

brodybits closed pull request #172: cleanup support for osx platform (macOS)
URL: https://github.com/apache/cordova-mobile-spec/pull/172
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/createmobilespec/createmobilespec.js b/createmobilespec/createmobilespec.js
index 2b0a3ef..493419b 100755
--- a/createmobilespec/createmobilespec.js
+++ b/createmobilespec/createmobilespec.js
@@ -115,7 +115,7 @@ var top_dir =             process.cwd() + path.sep,
                    .boolean("android").describe("android", "Add Android platform.")
                    .boolean("browser").describe("browser", "Add Browser platform.")
                    .boolean("ios").describe("ios", "Add iOS platform.")
-                   .boolean("osx").describe("osx", "Add osx platform.")
+                   .boolean("osx").describe("osx", "Add osx platform (macOS).")
                    .boolean("windows").describe("windows", "Add Windows (universal) platform.")
                    .boolean("plugman").describe("plugman", "Use {platform}/bin/create and plugman directly instead of the CLI.")
                    .boolean("global").describe("global", "Use the globally-installed `cordova` and the downloaded platforms/plugins from the registry instead of the local git repo.\n" +
@@ -216,27 +216,15 @@ var DEFAULT_PLUGINS = [
     'cordova-plugin-whitelist',
 ];
 
 // OSX has little support for the most of the plugins, so it gets its own default list
 var DEFAULT_PLUGINS_OSX = [
-    //'cordova-plugin-battery-status',
-    //'cordova-plugin-camera',
-    //'cordova-plugin-console',
-    //'cordova-plugin-contacts',
+    'cordova-plugin-camera',
     'cordova-plugin-device',
-    //'cordova-plugin-device-motion',
-    //'cordova-plugin-device-orientation',
-    //'cordova-plugin-dialogs',
     'cordova-plugin-file',
-    //'cordova-plugin-file-transfer',
-    //'cordova-plugin-geolocation',
-    //'cordova-plugin-globalization',
-    //'cordova-plugin-inappbrowser',
-    //'cordova-plugin-media',
-    //'cordova-plugin-media-capture',
-    //'cordova-plugin-network-information',
-    //'cordova-plugin-splashscreen',
-    //'cordova-plugin-statusbar',
-    //'cordova-plugin-vibration',
+    'cordova-plugin-inappbrowser',
+    // non-functional on osx platform (macOS), iOS,
+    // or any other non-Android platforms:
     'cordova-plugin-whitelist',
 ];
 
@@ -522,12 +510,12 @@ function pluginIdToDirName(id) {
 function installPlugins() {
     var plugins = DEFAULT_PLUGINS;
 
     // special override for osx
     if (argv.osx) {
         if (platforms.length > 1) {
-            console.warn('Warning: Testing more than one platform at once might cause problems with unsupported plugins for OSX');
+            console.warn('Warning: Testing more than one platform at once may cause issues with unsupported plugins for osx platform (macOS).');
         } else {
-            console.warn('Warning: Using reduced plugin list for OSX-only tests.');
+            console.warn('Warning: Using reduced plugin list for osx platform (macOS).');
             plugins = DEFAULT_PLUGINS_OSX;
         }
     }


 

----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services

---------------------------------------------------------------------
@@ -216,27 +216,15 @@ var DEFAULT_PLUGINS = [
 ];
 
-// OSX has little support for the most of the plugins, so it gets its own default list
+// osx platform (macOS) has little support for the most of the plugins,
+// so it gets its own default list
 var DEFAULT_PLUGINS_OSX = [
@@ -522,12 +510,12 @@ function pluginIdToDirName(id) {
     var plugins = DEFAULT_PLUGINS;
 
-    // special override for osx
+    // special override for osx platform (macOS)
     if (argv.osx) {
         if (platforms.length > 1) {
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org